@@ -45,7 +45,11 @@ async fn main() -> Result<()> {
     );
 
     // 6. deploy it with the constructor arguments
-    let contract = factory.deploy("initial value".to_string())?.send().await?;
+    let contract = factory
+        .deploy("initial value".to_string())?
+        .legacy()
+        .send()
+        .await?;
 
     // 7. get the contract's address
     let addr = contract.address();
@@ -55,7 +59,12 @@ async fn main() -> Result<()> {
 
     // 9. call the `setValue` method
     // (first `await` returns a PendingTransaction, second one waits for it to be mined)
-    let _receipt = contract.set_value("hi".to_owned()).send().await?.await?;
+    let _receipt = contract
+        .set_value("hi".to_owned())
+        .legacy()
+        .send()
+        .await?
+        .await?;
 
     // 10. get all events
     let logs = contract
